==> 0.2.0.tar.gz: test/src/html_test.dart <==
@TestGroup(description: 'tags.html')
library tags.test.html;

import 'dart:html';
import 'package:tags/tags.dart';
import 'package:bench/bench.dart';
import 'package:unittest/unittest.dart';

@Test('Test the &lt;a&gt; tag')
void test_a() => expect(a(), const isInstanceOf<AnchorElement>());

@Test('Test the &lt;area&gt; tag')
void test_area() => expect(area(), const isInstanceOf<AreaElement>());

@Test('Test the &lt;b&gt; tag')
void test_b() => expect(b(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;base&gt; tag')
void test_base() => expect(base(), const isInstanceOf<BaseElement>());

@Test('Test the &lt;body&gt; tag')
void test_body() => expect(body(), const isInstanceOf<BodyElement>());

@Test('Test the &lt;br&gt; tag')
void test_br() => expect(br(), const isInstanceOf<BRElement>());

@Test('Test the &lt;button&gt; tag')
void test_button() => expect(button(), const isInstanceOf<ButtonElement>());

@Test('Test the &lt;canvas&gt; tag')
void test_canvas() => expect(canvas(), const isInstanceOf<CanvasElement>());

@Test('Test the &lt;caption&gt; tag')
void test_caption() => 
    expect(caption(), const isInstanceOf<TableCaptionElement>());

@Test('Test the &lt;code&gt; tag')
void test_code() => expect(code(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;col&gt; tag')
void test_col() => expect(col(), const isInstanceOf<TableColElement>());

@Test('Test the &lt;content&gt; tag')
void test_content() => expect(content(), const isInstanceOf<ContentElement>());

@Test('Test the &lt;datalist&gt; tag')
void test_datalist() => 
    expect(datalist(), const isInstanceOf<DataListElement>());

@Test('Test the &lt;dd&gt; tag')
void test_dd() => expect(dd(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;del&gt; tag')
void test_del() => expect(del(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;details&gt; tag')
void test_details() => expect(details(), const isInstanceOf<DetailsElement>());

@Test('Test the &lt;div&gt; tag')
void test_div() => expect(div(), const isInstanceOf<DivElement>());

@Test('Test the &lt;dl&gt; tag')
void test_dl() => expect(dl(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;dt&gt; tag')
void test_dt() => expect(dt(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;embed&gt; tag')
void test_embed() => expect(embed(), const isInstanceOf<EmbedElement>());

@Test('Test the &lt;fieldset&gt; tag')
void test_fieldset() => 
    expect(fieldset(), const isInstanceOf<FieldSetElement>());

@Test('Test the &lt;form&gt; tag')
void test_form() => expect(form(), const isInstanceOf<FormElement>());

@Test('Test the &lt;h1&gt; tag')
void test_h1() => expect(h1(), const isInstanceOf<HeadingElement>());

@Test('Test the &lt;h2&gt; tag')
void test_h2() => expect(h2(), const isInstanceOf<HeadingElement>());

@Test('Test the &lt;h3&gt; tag')
void test_h3() => expect(h3(), const isInstanceOf<HeadingElement>());

@Test('Test the &lt;h4&gt; tag')
void test_h4() => expect(h4(), const isInstanceOf<HeadingElement>());

@Test('Test the &lt;h5&gt; tag')
void test_h5() => expect(h5(), const isInstanceOf<HeadingElement>());

@Test('Test the &lt;h6&gt; tag')
void test_h6() => expect(h6(), const isInstanceOf<HeadingElement>());

@Test('Test the &lt;head&gt; tag')
void test_head() => expect(head(), const isInstanceOf<HeadElement>());

@Test('Test the &lt;hr&gt; tag')
void test_hr() => expect(hr(), const isInstanceOf<HRElement>());

@Test('Test the &lt;html&gt; tag')
void test_html() => expect(html(), const isInstanceOf<HtmlHtmlElement>());

@Test('Test the &lt;i&gt; tag')
void test_i() => expect(i(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;img&gt; tag')
void test_img() => expect(img(), const isInstanceOf<ImageElement>());

@Test('Test the &lt;input&gt; tag')
void test_input() => expect(input(), const isInstanceOf<InputElement>());

@Test('Test the &lt;keygen&gt; tag')
void test_keygen() => expect(keygen(), const isInstanceOf<KeygenElement>());

@Test('Test the &lt;label&gt; tag')
void test_label() => expect(label(), const isInstanceOf<LabelElement>());

@Test('Test the &lt;legend&gt; tag')
void test_legend() => expect(legend(), const isInstanceOf<LegendElement>());

@Test('Test the &lt;li&gt; tag')
void test_li() => expect(li(), const isInstanceOf<LIElement>());

@Test('Test the &lt;link&gt; tag')
void test_link() => expect(link(), const isInstanceOf<LinkElement>());

@Test('Test the &lt;map&gt; tag')
void test_map() => expect(map(), const isInstanceOf<MapElement>());

@Test('Test the &lt;menu&gt; tag')
void test_menu() => expect(menu(), const isInstanceOf<MenuElement>());

@Test('Test the &lt;meter&gt; tag')
void test_meter() => expect(meter(), const isInstanceOf<MeterElement>());

@Test('Test the &lt;nav&gt; tag')
void test_nav() => expect(nav(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;object&gt; tag')
void test_object() => expect(object(), const isInstanceOf<ObjectElement>());

@Test('Test the &lt;ol&gt; tag')
void test_ol() => expect(ol(), const isInstanceOf<OListElement>());

@Test('Test the &lt;optgroup&gt; tag')
void test_optgroup() => 
    expect(optgroup(), const isInstanceOf<OptGroupElement>());

@Test('Test the &lt;option&gt; tag')
void test_option() => expect(option(), const isInstanceOf<OptionElement>());

@Test('Test the &lt;output&gt; tag')
void test_output() => expect(output(), const isInstanceOf<OutputElement>());

@Test('Test the &lt;p&gt; tag')
void test_p() => expect(p(), const isInstanceOf<ParagraphElement>());

@Test('Test the &lt;param&gt; tag')
void test_param() => expect(param(), const isInstanceOf<ParamElement>());

@Test('Test the &lt;pre&gt; tag')
void test_pre() => expect(pre(), const isInstanceOf<PreElement>());

@Test('Test the &lt;progress&gt; tag')
void test_progress() => 
    expect(progress(), const isInstanceOf<ProgressElement>());

@Test('Test the &lt;script&gt; tag')
void test_script() => expect(script(), const isInstanceOf<ScriptElement>());

@Test('Test the &lt;select&gt; tag')
void test_select() => expect(select(), const isInstanceOf<SelectElement>());

@Test('Test the &lt;source&gt; tag')
void test_source() => expect(source(), const isInstanceOf<SourceElement>());

@Test('Test the &lt;span&gt; tag')
void test_span() => expect(span(), const isInstanceOf<SpanElement>());

@Test('Test the &lt;style&gt; tag')
void test_style() => expect(style(), const isInstanceOf<StyleElement>());

@Test('Test the &lt;table&gt; tag')
void test_table() => expect(table(), const isInstanceOf<TableElement>());

@Test('Test the &lt;tbody&gt; tag')
void test_tbody() => expect(tbody(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;td&gt; tag')
void test_td() => expect(td(), const isInstanceOf<TableCellElement>());

@Test('Test the &lt;template&gt; tag')
void test_template() => 
    expect(template(), const isInstanceOf<TemplateElement>());

@Test('Test the &lt;textarea&gt; tag')
void test_textarea() => 
    expect(textarea(), const isInstanceOf<TextAreaElement>());

@Test('Test the &lt;tfoot&gt; tag')
void test_tfoot() => expect(tfoot(), const isInstanceOf<TableSectionElement>());

@Test('Test the &lt;th&gt; tag')
void test_th() => expect(th(), const isInstanceOf<TableCellElement>());

@Test('Test the &lt;thead&gt; tag')
void test_thead() => expect(thead(), const isInstanceOf<TableSectionElement>());

@Test('Test the &lt;title&gt; tag')
void test_title() => expect(title(), const isInstanceOf<TitleElement>());

@Test('Test the &lt;tr&gt; tag')
void test_tr() => expect(tr(), const isInstanceOf<TableRowElement>());

@Test('Test the &lt;track&gt; tag')
void test_track() => expect(track(), const isInstanceOf<TrackElement>());

@Test('Test the &lt;u&gt; tag')
void test_u() => expect(u(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;ul&gt; tag')
void test_ul() => expect(ul(), const isInstanceOf<UListElement>());

@Test('Test the &lt;video&gt; tag')
void test_video() => expect(video(), const isInstanceOf<VideoElement>());

==> 0.4.7.tar.gz: test/src/html_test.dart <==
@TestGroup(description: 'tags.html')
library tags.test.html;

import 'dart:html';
import 'package:tags/tags.dart';
import 'package:bench/bench.dart';
import 'package:unittest/unittest.dart';

@Test('Test the &lt;a&gt; tag')
void test_a() => expect(a(), const isInstanceOf<AnchorElement>());

@Test('Test the &lt;area&gt; tag')
void test_area() => expect(area(), const isInstanceOf<AreaElement>());

@Test('Test the &lt;article&gt; tag')
void test_article() => expect(article(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;aside&gt; tag')
void test_aside() => expect(aside(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;audio&gt; tag')
void test_audio() => expect(audio(), const isInstanceOf<AudioElement>());

@Test('Test the &lt;b&gt; tag')
void test_b() => expect(b(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;base&gt; tag')
void test_base() => expect(base(), const isInstanceOf<BaseElement>());

@Test('Test the &lt;body&gt; tag')
void test_body() => expect(body(), const isInstanceOf<BodyElement>());

@Test('Test the &lt;br&gt; tag')
void test_br() => expect(br(), const isInstanceOf<BRElement>());

@Test('Test the &lt;button&gt; tag')
void test_button() => expect(button(), const isInstanceOf<ButtonElement>());

@Test('Test the &lt;canvas&gt; tag')
void test_canvas() => expect(canvas(), const isInstanceOf<CanvasElement>());

@Test('Test the &lt;caption&gt; tag')
void test_caption() => 
    expect(caption(), const isInstanceOf<TableCaptionElement>());

@Test('Test the &lt;code&gt; tag')
void test_code() => expect(code(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;col&gt; tag')
void test_col() => expect(col(), const isInstanceOf<TableColElement>());

@Test('Test the &lt;content&gt; tag')
void test_content() => expect(content(), const isInstanceOf<ContentElement>());

@Test('Test the &lt;datalist&gt; tag')
void test_datalist() => 
    expect(datalist(), const isInstanceOf<DataListElement>());

@Test('Test the &lt;dd&gt; tag')
void test_dd() => expect(dd(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;del&gt; tag')
void test_del() => expect(del(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;details&gt; tag')
void test_details() => expect(details(), const isInstanceOf<DetailsElement>());

@Test('Test the &lt;div&gt; tag')
void test_div() => expect(div(), const isInstanceOf<DivElement>());

@Test('Test the &lt;dl&gt; tag')
void test_dl() => expect(dl(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;dt&gt; tag')
void test_dt() => expect(dt(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;embed&gt; tag')
void test_embed() => expect(embed(), const isInstanceOf<EmbedElement>());

@Test('Test the &lt;fieldset&gt; tag')
void test_fieldset() => 
    expect(fieldset(), const isInstanceOf<FieldSetElement>());

@Test('Test the &lt;footer&gt; tag')
void test_footer() => expect(footer(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;form&gt; tag')
void test_form() => expect(form(), const isInstanceOf<FormElement>());

@Test('Test the &lt;h1&gt; tag')
void test_h1() => expect(h1(), const isInstanceOf<HeadingElement>());

@Test('Test the &lt;h2&gt; tag')
void test_h2() => expect(h2(), const isInstanceOf<HeadingElement>());

@Test('Test the &lt;h3&gt; tag')
void test_h3() => expect(h3(), const isInstanceOf<HeadingElement>());

@Test('Test the &lt;h4&gt; tag')
void test_h4() => expect(h4(), const isInstanceOf<HeadingElement>());

@Test('Test the &lt;h5&gt; tag')
void test_h5() => expect(h5(), const isInstanceOf<HeadingElement>());

@Test('Test the &lt;h6&gt; tag')
void test_h6() => expect(h6(), const isInstanceOf<HeadingElement>());

@Test('Test the &lt;head&gt; tag')
void test_head() => expect(head(), const isInstanceOf<HeadElement>());

@Test('Test the &lt;header&gt; tag')
void test_header() => expect(header(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;hr&gt; tag')
void test_hr() => expect(hr(), const isInstanceOf<HRElement>());

@Test('Test the &lt;html&gt; tag')
void test_html() => expect(html(), const isInstanceOf<HtmlHtmlElement>());

@Test('Test the &lt;i&gt; tag')
void test_i() => expect(i(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;iframe&gt; tag')
void test_iframe() => expect(iframe(), const isInstanceOf<IFrameElement>());

@Test('Test the &lt;img&gt; tag')
void test_img() => expect(img(), const isInstanceOf<ImageElement>());

@Test('Test the &lt;input&gt; tag')
void test_input() => expect(input(), const isInstanceOf<InputElement>());

@Test('Test the &lt;keygen&gt; tag')
void test_keygen() => expect(keygen(), const isInstanceOf<KeygenElement>());

@Test('Test the &lt;label&gt; tag')
void test_label() => expect(label(), const isInstanceOf<LabelElement>());

@Test('Test the &lt;legend&gt; tag')
void test_legend() => expect(legend(), const isInstanceOf<LegendElement>());

@Test('Test the &lt;li&gt; tag')
void test_li() => expect(li(), const isInstanceOf<LIElement>());

@Test('Test the &lt;link&gt; tag')
void test_link() => expect(link(), const isInstanceOf<LinkElement>());

@Test('Test the &lt;map&gt; tag')
void test_map() => expect(map(), const isInstanceOf<MapElement>());

@Test('Test the &lt;menu&gt; tag')
void test_menu() => expect(menu(), const isInstanceOf<MenuElement>());

@Test('Test the &lt;meter&gt; tag')
void test_meter() => expect(meter(), const isInstanceOf<MeterElement>());

@Test('Test the &lt;nav&gt; tag')
void test_nav() => expect(nav(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;object&gt; tag')
void test_object() => expect(object(), const isInstanceOf<ObjectElement>());

@Test('Test the &lt;ol&gt; tag')
void test_ol() => expect(ol(), const isInstanceOf<OListElement>());

@Test('Test the &lt;optgroup&gt; tag')
void test_optgroup() => 
    expect(optgroup(), const isInstanceOf<OptGroupElement>());

@Test('Test the &lt;option&gt; tag')
void test_option() => expect(option(), const isInstanceOf<OptionElement>());

@Test('Test the &lt;output&gt; tag')
void test_output() => expect(output(), const isInstanceOf<OutputElement>());

@Test('Test the &lt;p&gt; tag')
void test_p() => expect(p(), const isInstanceOf<ParagraphElement>());

@Test('Test the &lt;param&gt; tag')
void test_param() => expect(param(), const isInstanceOf<ParamElement>());

@Test('Test the &lt;pre&gt; tag')
void test_pre() => expect(pre(), const isInstanceOf<PreElement>());

@Test('Test the &lt;progress&gt; tag')
void test_progress() => 
    expect(progress(), const isInstanceOf<ProgressElement>());

@Test('Test the &lt;script&gt; tag')
void test_script() => expect(script(), const isInstanceOf<ScriptElement>());

@Test('Test the &lt;section&gt; tag')
void test_section() => expect(section(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;select&gt; tag')
void test_select() => expect(select(), const isInstanceOf<SelectElement>());

@Test('Test the &lt;source&gt; tag')
void test_source() => expect(source(), const isInstanceOf<SourceElement>());

@Test('Test the &lt;span&gt; tag')
void test_span() => expect(span(), const isInstanceOf<SpanElement>());

@Test('Test the &lt;style&gt; tag')
void test_style() => expect(style(), const isInstanceOf<StyleElement>());

@Test('Test the &lt;table&gt; tag')
void test_table() => expect(table(), const isInstanceOf<TableElement>());

@Test('Test the &lt;tbody&gt; tag')
void test_tbody() => expect(tbody(), const isInstanceOf<TableSectionElement>());

@Test('Test the &lt;td&gt; tag')
void test_td() => expect(td(), const isInstanceOf<TableCellElement>());

@Test('Test the &lt;template&gt; tag')
void test_template() => 
    expect(template(), const isInstanceOf<TemplateElement>());

@Test('Test the &lt;textarea&gt; tag')
void test_textarea() => 
    expect(textarea(), const isInstanceOf<TextAreaElement>());

@Test('Test the &lt;tfoot&gt; tag')
void test_tfoot() => expect(tfoot(), const isInstanceOf<TableSectionElement>());

@Test('Test the &lt;th&gt; tag')
void test_th() => expect(th(), const isInstanceOf<TableCellElement>());

@Test('Test the &lt;thead&gt; tag')
void test_thead() => expect(thead(), const isInstanceOf<TableSectionElement>());

@Test('Test the &lt;title&gt; tag')
void test_title() => expect(title(), const isInstanceOf<TitleElement>());

@Test('Test the &lt;tr&gt; tag')
void test_tr() => expect(tr(), const isInstanceOf<TableRowElement>());

@Test('Test the &lt;track&gt; tag')
void test_track() => expect(track(), const isInstanceOf<TrackElement>());

@Test('Test the &lt;u&gt; tag')
void test_u() => expect(u(), const isInstanceOf<HtmlElement>());

@Test('Test the &lt;ul&gt; tag')
void test_ul() => expect(ul(), const isInstanceOf<UListElement>());

@Test('Test the &lt;video&gt; tag')
void test_video() => expect(video(), const isInstanceOf<VideoElement>());
